package dev.fyloz.colorrecipesexplorer.repository

import dev.fyloz.colorrecipesexplorer.model.Mix
import dev.fyloz.colorrecipesexplorer.model.MixType
import org.springframework.data.jpa.repository.JpaRepository
import org.springframework.data.jpa.repository.Modifying
import org.springframework.data.jpa.repository.Query

interface MixRepository : JpaRepository<Mix, Long> {
    /** Finds all mixes with the given [mixType]. */
    fun findAllByMixType(mixType: MixType): Collection<Mix>

    /** Updates the [location] of the [Mix] with the given [id]. */
    @Modifying
    @Query("UPDATE Mix m SET m.location = :location WHERE m.id = :id")
    fun updateLocationById(id: Long, location: String?)

    @Query(
        """
        select case when(count(mm.id) > 0) then false else true end
        from Mix m
        left join MixMaterial mm on m.mixType.material.id = mm.material.id
        where m.id = :id
    """
    )
    fun canBeDeleted(id: Long): Boolean
}
